Module proto

Module proto 

Modules

block_streaming_client
Generated client implementations.
l4_book_update
Nested message and enum types in L4BookUpdate.
order_book_streaming_client
Generated client implementations.
streaming_client
Generated client implementations.
subscribe_request
Nested message and enum types in SubscribeRequest.
subscribe_update
Nested message and enum types in SubscribeUpdate.

Structs

Block
FilterValues
Container for filter values
L2BookRequest
Request parameters for L2 book streaming.
L2BookUpdate
An L2 book update: full snapshot of aggregated price levels at a point in time.
L2Level
A single aggregated price level.
L4BookDiff
Incremental L4 book diff: raw order statuses and book diffs for one block.
L4BookRequest
Request parameters for L4 book streaming.
L4BookSnapshot
Full L4 order book snapshot for a single coin.
L4BookUpdate
An L4 book update: either a full snapshot or an incremental diff.
L4Order
A single L4 order with full details.
Ping
PingRequest
PingResponse
Pong
StreamResponse
StreamSubscribe
SubscribeRequest
— Requests —
SubscribeUpdate
— Responses —
Timestamp

Enums

StreamType
— Data Types —